@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2016 by Dominique Dumont.
+# This software is Copyright (c) 2015-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -28,9 +28,11 @@ XDG
 Desktop Entry Specification .desktop
 files, which are in turn inspired by Microsoft Windows
 .ini files.
+
 This man page lists the common configuration options of all
 the unit types. These options need to be configured in the [Unit]
 or [Install] sections of the unit files.
+
 In addition to the generic [Unit] and [Install] sections
 described here, each unit may have a type-specific section, e.g.
 [Service] for a service unit. See the respective man pages for
@@ -46,6 +48,8 @@ L<systemd.path(5)>,
 L<systemd.timer(5)>,
 L<systemd.slice(5)>,
 L<systemd.scope(5)>.
+
+
 Various settings are allowed to be specified more than once,
 in which case the interpretation depends on the setting. Often,
 multiple settings form a list, and setting to an empty value
@@ -54,8 +58,10 @@ this is allowed, it is mentioned in the description of the
 setting. Note that using multiple assignments to the same value
 makes the unit file incompatible with parsers for the XDG
 .desktop file format.
+
 Unit files are loaded from a set of paths determined during
 compilation, described in the next section.
+
 Unit files may contain additional options on top of those
 listed here. If systemd encounters an unknown option, it will
 write a warning log message but continue loading the unit. If an
@@ -63,6 +69,7 @@ option or section name is prefixed with C<X->, it is
 ignored completely by systemd. Options within an ignored section
 do not need the prefix. Applications may use this to include
 additional information in the unit files.
+
 Boolean arguments used in unit files can be written in
 various formats. For positive settings the strings
 C<1>, C<yes>, C<true>
@@ -70,6 +77,7 @@ and C<on> are equivalent. For negative settings, the
 strings C<0>, C<no>,
 C<false> and C<off> are
 equivalent.
+
 Time span values encoded in unit files can be written in various formats. A stand-alone
 number specifies a time in seconds.  If suffixed with a time unit, the unit is honored. A
 concatenation of multiple values with units is supported, in which case the values are added
@@ -78,10 +86,12 @@ up. Example: C<50> refers to 50 seconds; C<2min\x{a0}200ms> refers to
 C<s>, C<min>, C<h>, C<d>,
 C<w>, C<ms>, C<us>.  For details see
 L<systemd.time(7)>.
+
 Empty lines and lines starting with C<#> or C<;> are
 ignored. This may be used for commenting. Lines ending in a backslash are concatenated with the
 following line while reading and the backslash is replaced by a space character. This may be
 used to wrap long lines.
+
 Units can be aliased (have an alternative name), by creating a symlink from the new name
 to the existing name in one of the unit search paths. For example,
 systemd-networkd.service has the alias
@@ -98,6 +108,7 @@ status, \x{2026}, and in unit dependency directives C<Wants>,
 C<Requires>, C<Before>, C<After>, \x{2026}, with the
 limitation that aliases specified through C<Alias> are only effective when the
 unit is enabled. Aliases cannot be used with the preset command.
+
 Along with a unit file foo.service, the directory
 foo.service.wants/ may exist. All unit files symlinked from such a
 directory are implicitly added as dependencies of type C<Wants> to the unit.
@@ -109,6 +120,7 @@ L<systemctl(1)>
 tool which reads information from the [Install] section of unit files (see below). A similar
 functionality exists for C<Requires> type dependencies as well, the directory
 suffix is .requires/ in this case.
+
 Along with a unit file foo.service, a \"drop-in\" directory
 foo.service.d/ may exist. All files with the suffix
 C<.conf> from this directory will be parsed after the file itself is
@@ -119,12 +131,14 @@ subdirectory and read its C<.conf> files, followed by the template
 C<.d/> subdirectory and the C<.conf> files there. Also note that
 settings from the C<[Install]> section are not honored in drop-in unit files,
 and have no effect.
+
 In addition to /etc/systemd/system, the drop-in C<.d>
 directories for system services can be placed in /usr/lib/systemd/system or
 /run/systemd/system directories. Drop-in files in /etc
 take precedence over those in /run which in turn take precedence over those
 in /usr/lib. Drop-in files under any of these directories take precedence
 over unit files wherever located.
+
 Some unit names reflect paths existing in the file system
 namespace. Example: a device unit
 dev-sda.device refers to a device with the
@@ -141,6 +155,7 @@ paths during transformation. This escaping is reversible. Properly
 escaped paths can be generated using the
 L<systemd-escape(1)>
 command.
+
 Optionally, units may be instantiated from a
 template file at runtime. This allows creation of
 multiple units from a single configuration file. If
@@ -156,19 +171,23 @@ and no file by that name is found, systemd will look
 for getty\@.service and
 instantiate a service from that configuration file if
 it is found.
+
 To refer to the instance string from within the
 configuration file you may use the special C<%i>
 specifier in many of the configuration options. See below for
 details.
+
 If a unit file is empty (i.e. has the file size 0) or is
 symlinked to /dev/null, its configuration
 will not be loaded and it appears with a load state of
 C<masked>, and cannot be activated. Use this as an
 effective way to fully disable a unit, making it impossible to
 start it even manually.
+
 The unit file format is covered by the
 Interface
 Stability Promise.
+
 Additional units might be loaded into systemd (\"linked\")
 from directories not on the unit load path. See the
 link command for
@@ -247,7 +266,9 @@ delay between them if foo.service is
 activated. Often, it is a better choice to use
 C<Wants> instead of
 C<Requires> in order to achieve a system that
-is more robust when dealing with failing services.Note that dependencies of this type may also be
+is more robust when dealing with failing services.
+
+Note that dependencies of this type may also be
 configured outside of the unit configuration file by adding a
 symlink to a .requires/ directory
 accompanying the unit file. For details, see
@@ -256,31 +277,43 @@ above.',
       },
       'Requisite',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => 'Similar to C<Requires>.
 However, if the units listed here are not started already,
 they will not be started and the transaction will fail
 immediately. ',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'Wants',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => 'A weaker version of
 C<Requires>. Units listed in this option will
 be started if the configuring unit is. However, if the listed
 units fail to start or cannot be added to the transaction,
 this has no impact on the validity of the transaction as a
 whole. This is the recommended way to hook start-up of one
-unit to the start-up of another unit.Note that dependencies of this type may also be
+unit to the start-up of another unit.
+
+Note that dependencies of this type may also be
 configured outside of the unit configuration file by adding
 symlinks to a .wants/ directory
 accompanying the unit file. For details, see
 above.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'BindsTo',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => 'Configures requirement dependencies, very
 similar in style to C<Requires>, however in
 addition to this behavior, it also declares that this unit is
@@ -289,29 +322,37 @@ Units can suddenly, unexpectedly disappear if a service
 terminates on its own choice, a device is unplugged or a mount
 point unmounted without involvement of
 systemd.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'PartOf',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => "Configures dependencies similar to
 C<Requires>, but limited to stopping and
 restarting of units. When systemd stops or restarts the units
 listed here, the action is propagated to this unit. Note that
 this is a one-way dependency\x{a0}\x{2014} changes to this unit do not
 affect the listed units. ",
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'Conflicts',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => 'A space-separated list of unit names.
 Configures negative requirement dependencies. If a unit has a
 C<Conflicts> setting on another unit,
 starting the former will stop the latter and vice versa. Note
 that this setting is independent of and orthogonal to the
 C<After> and C<Before>
-ordering dependencies.If a unit A that conflicts with a unit B is scheduled to
+ordering dependencies.
+
+If a unit A that conflicts with a unit B is scheduled to
 be started at the same time as B, the transaction will either
 fail (in case both are required part of the transaction) or be
 modified to be fixed (in case one or both jobs are not a
@@ -319,8 +360,7 @@ required part of the transaction). In the latter case, the job
 that is not the required will be removed, or in case both are
 not required, the unit that conflicts will be started and the
 unit that is conflicted is stopped.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'Before',
       {
@@ -469,7 +509,9 @@ joined.',
         'description' => 'Takes a space-separated list of absolute
 paths. Automatically adds dependencies of type
 C<Requires> and C<After> for
-all mount units required to access the specified path.Mount points marked with C<noauto> are not
+all mount units required to access the specified path.
+
+Mount points marked with C<noauto> are not
 mounted automatically and will be ignored for the purposes of
 this option. If such a mount should be a requirement for this
 unit, direct dependencies on the mount units may be added
@@ -617,7 +659,9 @@ except for device units. NB: this timeout is independent from any unit-specific
 timeout set with C<TimeoutStartSec> in service units) as the job timeout has no effect on the
 unit itself, only on the job that might be pending for it. Or in other words: unit-specific timeouts are useful
 to abort unit state changes, and revert them. The job timeout set with this option however is useful to abort
-only the job waiting for the unit state to change.C<JobTimeoutAction>
+only the job waiting for the unit state to change.
+
+C<JobTimeoutAction>
 optionally configures an additional
 action to take when the time-out is
 hit. It takes the same values as the
@@ -643,7 +687,9 @@ except for device units. NB: this timeout is independent from any unit-specific
 timeout set with C<TimeoutStartSec> in service units) as the job timeout has no effect on the
 unit itself, only on the job that might be pending for it. Or in other words: unit-specific timeouts are useful
 to abort unit state changes, and revert them. The job timeout set with this option however is useful to abort
-only the job waiting for the unit state to change.C<JobTimeoutAction>
+only the job waiting for the unit state to change.
+
+C<JobTimeoutAction>
 optionally configures an additional
 action to take when the time-out is
 hit. It takes the same values as the
@@ -669,7 +715,9 @@ except for device units. NB: this timeout is independent from any unit-specific
 timeout set with C<TimeoutStartSec> in service units) as the job timeout has no effect on the
 unit itself, only on the job that might be pending for it. Or in other words: unit-specific timeouts are useful
 to abort unit state changes, and revert them. The job timeout set with this option however is useful to abort
-only the job waiting for the unit state to change.C<JobTimeoutAction>
+only the job waiting for the unit state to change.
+
+C<JobTimeoutAction>
 optionally configures an additional
 action to take when the time-out is
 hit. It takes the same values as the
